
.. image:: https://badge.fury.io/py/galaxy-test-selenium.svg
   :target: https://pypi.org/project/galaxy-test-selenium/



Overview
--------

The Galaxy_ Selenium tests.

* Free software: Academic Free License version 3.0
* Code: https://github.com/galaxyproject/galaxy

.. _Galaxy: http://galaxyproject.org/
